==> cgal-3.1.tbz: include/CGAL/kernel_basic.h <==
// Copyright (c) 1999,2003  Utrecht University (The Netherlands),
// ETH Zurich (Switzerland), Freie Universitaet Berlin (Germany),
// INRIA Sophia-Antipolis (France), Martin-Luther-University Halle-Wittenberg
// (Germany), Max-Planck-Institute Saarbruecken (Germany), RISC Linz (Austria),
// and Tel-Aviv University (Israel).  All rights reserved.
//
// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; version 2.1 of the License.
// See the file LICENSE.LGPL distributed with CGAL.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $Source: /CVSROOT/CGAL/Packages/Kernel_23/include/CGAL/kernel_basic.h,v $
// $Revision: 1.11 $ $Date: 2003/12/03 16:37:02 $
// $Name:  $
//
// Author(s)     : Stefan Schirra
 

#ifndef CGAL_KERNEL_BASIC_H
#define CGAL_KERNEL_BASIC_H

#ifndef CGAL_KERNEL_INLINE
#  define CGAL_KERNEL_INLINE inline
#endif

#ifndef CGAL_KERNEL_MEDIUM_INLINE
#  define CGAL_KERNEL_MEDIUM_INLINE
#endif

#ifndef CGAL_KERNEL_LARGE_INLINE
#  define CGAL_KERNEL_LARGE_INLINE
#endif

#include <CGAL/Kernel_traits.h>
#include <CGAL/functional_base.h>
#include <CGAL/Kernel/global_functions.h>

#endif // CGAL_KERNEL_BASIC_H

==> cgal-3.4_1.tbz: include/CGAL/kernel_basic.h <==
// Copyright (c) 1999,2003  Utrecht University (The Netherlands),
// ETH Zurich (Switzerland), Freie Universitaet Berlin (Germany),
// INRIA Sophia-Antipolis (France), Martin-Luther-University Halle-Wittenberg
// (Germany), Max-Planck-Institute Saarbruecken (Germany), RISC Linz (Austria),
// and Tel-Aviv University (Israel).  All rights reserved.
//
// This file is part of CGAL (www.cgal.org); you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; version 2.1 of the License.
// See the file LICENSE.LGPL distributed with CGAL.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.4-branch/Kernel_23/include/CGAL/kernel_basic.h $
// $Id: kernel_basic.h 44361 2008-07-23 14:50:58Z hoffmann $
// 
//
// Author(s)     : Stefan Schirra
 
#ifndef CGAL_KERNEL_BASIC_H
#define CGAL_KERNEL_BASIC_H

#ifndef CGAL_KERNEL_INLINE
#  define CGAL_KERNEL_INLINE inline
#endif

#ifndef CGAL_KERNEL_MEDIUM_INLINE
#  define CGAL_KERNEL_MEDIUM_INLINE
#endif

#ifndef CGAL_KERNEL_LARGE_INLINE
#  define CGAL_KERNEL_LARGE_INLINE
#endif

#include <CGAL/kernel_assertions.h>
#include <CGAL/enum.h>
#include <CGAL/aff_transformation_tags.h>
#include <CGAL/Object.h>
#include <CGAL/Qualified_result_of.h>
#include <CGAL/Kernel_traits.h>

#endif // CGAL_KERNEL_BASIC_H
